==> haskell-hoauth2-2.9.0-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.9.0
visibility:           public
id:                   hoauth2-2.9.0-9JbwdkIkQB92lFhWDVG33T
key:                  hoauth2-2.9.0-9JbwdkIkQB92lFhWDVG33T
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  1fbdf4764339db68a6b1a353d37f8b0f
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.9.0-9JbwdkIkQB92lFhWDVG33T
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv base-4.17.2.1
    base64-0.4.2.4-31WPpcDxxba703UJmwu2og binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9aiao6Baet5LbFVZqeOgvR
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    http-conduit-2.3.9.1-G9skUe0R0eKFLtgtZaUIye
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-EEchkFkRPWm3e4QTlSIAG1
    uri-bytestring-aeson-0.1.0.9-60TpkEjCpMODSITbTj8VUf

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hoauth2-2.9.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.9.0
visibility:           public
id:                   hoauth2-2.9.0-5mCBmI0qLMU61J2bXZZCZG
key:                  hoauth2-2.9.0-5mCBmI0qLMU61J2bXZZCZG
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  37d7ff58dcbc32b963e224c1688fc7d8
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.9.0-5mCBmI0qLMU61J2bXZZCZG
depends:
    aeson-2.1.2.1-LRjlcarryWV47QfBrWIlNe base-4.17.2.1
    base64-0.4.2.4-8F5MarADfzsLQuRTZZCB8u binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-3yYlvSkPYZuEKec1R0Vp9e
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    http-conduit-2.3.9.1-KSzVopJIkMUDWWEoBzLNsW
    http-types-0.12.4-1ct1dd8yFZbHBxvHAGckYw
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-BZyqcVYPzEmG0599ORjr0w
    uri-bytestring-aeson-0.1.0.9-6jHjCNG4hx0KvYu7DzDb2S

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
